@@ -4,7 +4,7 @@ from typing import Optional
 from pydantic import Field
 
 from .base_model import BaseModel
-from .utils import HashableMapping, HashableSequence, HashableSet
+from .utils import HashableMapping, HashableSet
 from .shared import Attribute, CURIE
 
 
